@@ -44,8 +44,7 @@ pub fn app() -> App<'static> {
             Arg::new("initials")
                 .about("Initials of the mit to put in the commit")
                 .multiple_values(true)
-                .required(true)
-                .min_values(1),
+                .required_unless_present("completion"),
         )
         .arg(
             Arg::new("file")
@@ -77,6 +76,13 @@ pub fn app() -> App<'static> {
                 .takes_value(true)
                 .default_value("60"),
         )
+        .arg(Arg::new("completion").long("completion").possible_values(&[
+            "bash",
+            "elvish",
+            "fish",
+            "powershell",
+            "zsh",
+        ]))
 }
 
 #[cfg(test)]
